@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    commands/exportsecretsubkeycommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2022 g10 Code GmbH
     SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
@@ -13,7 +11,7 @@
 #include "command_p.h"
 #include "exportsecretsubkeycommand.h"
 
-#include "fileoperationspreferences.h"
+#include <settings.h>
 #include <utils/applicationstate.h>
 #include <utils/filedialog.h>
 
@@ -41,7 +39,7 @@ namespace
 
 QString openPGPCertificateFileExtension()
 {
-    return outputFileExtension(Class::OpenPGP | Class::Ascii | Class::Certificate, FileOperationsPreferences().usePGPFileExt());
+    return outputFileExtension(Class::OpenPGP | Class::Ascii | Class::Certificate, Settings().usePGPFileExt());
 }
 
 QString proposeFilename(const std::vector<Subkey> &subkeys)
