@@ -1,6 +1,4 @@
 /*
-    kleopageconfigdialog.cpp
-
     This file is part of Kleopatra
     SPDX-FileCopyrightText: 2016 Bundesamt für Sicherheit in der Informationstechnik
     SPDX-FileContributor: Intevation GmbH
@@ -185,7 +183,6 @@ void KleoPageConfigDialog::slotHelpClicked()
 
 void KleoPageConfigDialog::addModule(const QString &name, const QString &docPath, const QString &icon, KleoConfigModule *module)
 {
-    mModules << module;
     module->load();
     auto item = addPage(module, name);
     item->setIcon(QIcon::fromTheme(icon));
