@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/gui/wizardpage.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -61,7 +59,7 @@ Q_SIGNALS:
     void windowTitleChanged(const QString &title);
 
 protected:
-    virtual void onNext();
+    virtual bool onNext();
 
 private:
     class Private;
