@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    systemtrayicon.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -20,11 +18,7 @@
 
 #include <utils/clipboardmenu.h>
 
-#include <commands/decryptverifyclipboardcommand.h>
-#include <commands/encryptclipboardcommand.h>
-#include <commands/importcertificatefromclipboardcommand.h>
 #include <commands/setinitialpincommand.h>
-#include <commands/signclipboardcommand.h>
 
 #include <KAboutApplicationDialog>
 #include <KAboutData>
