@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    uiserver/decryptverifycommandfilesbase.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
@@ -11,9 +9,10 @@
 
 #include "assuancommand.h"
 
-#include <utils/pimpl_ptr.h>
 #include <utils/types.h>
 
+#include <memory>
+
 namespace Kleo
 {
 
@@ -54,6 +53,6 @@ public:
     class Private;
 
 private:
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 }
