@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    uiserver/verifycommand.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -11,8 +9,6 @@
 
 #include "assuancommand.h"
 
-#include <utils/pimpl_ptr.h>
-
 namespace Kleo
 {
 class VerifyCommand : public AssuanCommandMixin<VerifyCommand, DecryptVerifyCommandEMailBase>
