@@ -7,13 +7,17 @@
 #pragma once
 
 #include <QObject>
+#include <QPointer>
+
 class KActionMenu;
 class QAction;
 class MainWindow;
+
 namespace Kleo
 {
 class Command;
 }
+
 class ClipboardMenu : public QObject
 {
     Q_OBJECT
@@ -27,21 +31,19 @@ public:
 
 private Q_SLOTS:
     void slotImportClipboard();
+    void slotSignEncryptClipboard();
+    void slotSignClipboard();
     void slotEncryptClipboard();
-    void slotOpenPGPSignClipboard();
-    void slotSMIMESignClipboard();
     void slotDecryptVerifyClipboard();
-    void slotEnableDisableActions();
 
 private:
     void startCommand(Kleo::Command *cmd);
 
-    KActionMenu *mClipboardMenu;
-    QAction *mImportClipboardAction;
-    QAction *mEncryptClipboardAction;
-    QAction *mSmimeSignClipboardAction;
-    QAction *mOpenPGPSignClipboardAction;
-    QAction *mDecryptVerifyClipboardAction;
-    MainWindow *mWindow;
+    QPointer<KActionMenu> mClipboardMenu;
+    QPointer<QAction> mImportClipboardAction;
+    QPointer<QAction> mSignClipboardAction;
+    QPointer<QAction> mEncryptClipboardAction;
+    QPointer<QAction> mSignEncryptClipboardAction;
+    QPointer<QAction> mDecryptVerifyClipboardAction;
+    QPointer<MainWindow> mWindow;
 };
-
