@@ -26,8 +26,7 @@ HRESULT w32_shgetfolderpath(HWND a, int b, HANDLE c, DWORD d, LPSTR e);
 /* Return a string from the Win32 Registry or NULL in case of error.
    Caller must release the return value.  A NULL for root is an alias
    for HKEY_CURRENT_USER, HKEY_LOCAL_MACHINE in turn.  */
-char *read_w32_registry_string(const char *root, const char *dir,
-                               const char *name);
+char *read_w32_registry_string(const char *root, const char *dir, const char *name);
 
 #ifdef __cplusplus
 #if 0
@@ -35,4 +34,3 @@ char *read_w32_registry_string(const char *root, const char *dir,
 #endif
 }
 #endif
-
