@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    view/searchbar.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -32,6 +30,7 @@ public:
     QLineEdit *lineEdit() const;
 
     void updateClickMessage(const QString &shortcutStr);
+    void addCustomKeyFilter(const std::shared_ptr<KeyFilter> &keyFilter);
 
 public Q_SLOTS:
     void setStringFilter(const QString &text);
