@@ -10,6 +10,7 @@
 
 #include "urllabel.h"
 
+#include <QFocusEvent>
 #include <QUrl>
 
 using namespace Kleo;
@@ -39,9 +40,9 @@ void UrlLabel::setUrl(const QUrl &url, const QString &text)
 
 void UrlLabel::focusInEvent(QFocusEvent *event)
 {
-    // immediately focus the URL when the label get focus
+    // immediately focus the URL when the label get focus (except on mouse click)
     QLabel::focusInEvent(event);
-    if (!hasSelectedText()) {
+    if (!hasSelectedText() && event->reason() != Qt::MouseFocusReason) {
         QMetaObject::invokeMethod(
             this,
             [this]() {
